@@ -1,7 +1,7 @@
 package TableData::Object;
 
-our $DATE = '2014-08-16'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $DATE = '2015-09-06'; # DATE
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -196,7 +196,7 @@ TableData::Object - Manipulate table data
 
 =head1 VERSION
 
-This document describes version 0.01 of TableData::Object (from Perl distribution TableData-Object), released on 2014-08-16.
+This document describes version 0.02 of TableData::Object (from Perl distribution TableData-Object), released on 2015-09-06.
 
 =head1 SYNOPSIS
 
@@ -298,8 +298,6 @@ Get a single column data.
 
 =head2 as_aohos() => array of hash of scalar
 
-=head1 TODO
-
 =head1 SEE ALSO
 
 L<TableDef>
@@ -322,11 +320,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
